<?php
/**
 * @package   AkeebaBackup
 * @copyright Copyright (c)2006-2016 Nicholas K. Dionysopoulos
 * @license   GNU General Public License version 3, or later
 */

// Protect from unauthorized access
defined('_JEXEC') or die();

/** @var  \Akeeba\Backup\Admin\View\Manage\Html  $this */

/** @var  array  $record */

use Akeeba\Backup\Admin\Helper\Utils;

if (!isset($record['remote_filename']))
{
	$record['remote_filename'] = '';
}

$archiveExists    = $record['meta'] == 'ok';
$showManageRemote = in_array($record['meta'], array('ok', 'remote')) && !empty($record['remote_filename']) && (AKEEBA_PRO == 1);
$showUploadRemote = $archiveExists && empty($record['remote_filename']) && ($this->enginesPerProfile[$record['profile_id']] != 'none') && ($record['meta'] != 'obsolete') && (AKEEBA_PRO == 1);
$showDownload     = $archiveExists;
$showViewLog      = isset($record['backupid']) && !empty($record['backupid']);
$postProcEngine   = '';
$thisPart         = '';
$thisID           = urlencode($record['id']);

if ($showUploadRemote)
{
	$postProcEngine   = $this->enginesPerProfile[$record['profile_id']];
	$showUploadRemote = !empty($postProcEngine);
}

?>
<div class="hide fade">
	<div id="akeeba-buadmin-{{(int)$record['id']}}" tabindex="-1" role="dialog" class="akeeba-bootstrap">
		<h3>@lang('COM_AKEEBA_BUADMIN_LBL_BACKUPINFO')</h3>
		<p>
			<strong>@lang('COM_AKEEBA_BUADMIN_LBL_ARCHIVEEXISTS')</strong>
			<br/>
			@if ($record['meta'] == 'ok')
			<span class="label label-success">
				@lang('JYES')
			</span>
			@else
			<span class="label label-important">
				@lang('JNO')
			</span>
			@endif
		</p>
		<p>
			<strong>@lang('COM_AKEEBA_BUADMIN_LBL_ARCHIVEPATH' . ($archiveExists ? '' : '_PAST'))</strong>
			<br/>
			<span class="label">
				{{{Utils::getRelativePath(JPATH_SITE, dirname($record['absolute_path']))}}}
			</span>
		</p>
		<p>
			<strong>@lang('COM_AKEEBA_BUADMIN_LBL_ARCHIVENAME' . ($archiveExists ? '' : '_PAST'))</strong>
			<br/>
			<span class="label">
			{{{$record['archivename']}}}
			</span>
		</p>
	</div>

	<div id="akeeba-buadmin-download-{{(int)$record['id']}}" tabindex="-2" role="dialog" class="akeeba-bootstrap">
		<div class="alert">
			<h4>
				<span class="fa fa-warning"></span>
				@lang('COM_AKEEBA_BUADMIN_LBL_DOWNLOAD_TITLE')
			</h4>
			@lang('COM_AKEEBA_BUADMIN_LBL_DOWNLOAD_WARNING')
		</div>

		@if ($record['multipart'] < 2)
			<a class="btn btn-mini" href="javascript:confirmDownload('{{$thisID}}', '');">
				<span class="fa fa-fw fa-download"></span>
				@lang('COM_AKEEBA_BUADMIN_LOG_DOWNLOAD')
			</a>
		@endif
		@if ($record['multipart'] >= 2)
			<div>
				@sprintf('COM_AKEEBA_BUADMIN_LBL_DOWNLOAD_PARTS', (int)$record['multipart'])
			</div>
			@for ($count = 0; $count < $record['multipart']; $count++)
				@if ($count > 0)
				&bull;
				@endif
				<a class="btn btn-mini" href="javascript:confirmDownload('{{$thisID}}', '{{urlencode($count)}}');">
					<span class="fa fa-fw fa-download"></span>
					@sprintf('COM_AKEEBA_BUADMIN_LABEL_PART', $count)
				</a>
			@endfor
		@endif
	</div>
</div>

@if ($showManageRemote)
<div style="padding-bottom: 3pt;">
	<a class="btn btn-primary modal akeeba_remote_management_link"
	   href="index.php?option=com_akeeba&view=RemoteFiles&tmpl=component&task=listactions&id={{(int)$record['id']}}"
	   rel="{handler: 'iframe', size: {x: 450, y: 280}, onClose: function(){window.location='index.php?option=com_akeeba&view=Manage'}}">
		<span class="fa fa-fw fa-cloud"></span>
		@lang('COM_AKEEBA_BUADMIN_LABEL_REMOTEFILEMGMT')
	</a>
</div>
@elseif ($showUploadRemote)
	<a class="btn btn-primary modal akeeba_upload"
	   href="index.php?option=com_akeeba&view=Upload&tmpl=component&task=start&id={{(int)$record['id']}}"
	   rel="{handler: 'iframe', size: {x: 350, y: 200}, onClose: function(){window.location='index.php?option=com_akeeba&view=Manage'}}"
	   title="@sprintf('COM_AKEEBA_TRANSFER_DESC', JText::_("ENGINE_POSTPROC_{$postProcEngine}_TITLE"))">
		<span class="fa fa-fw fa-cloud-upload"></span>
		@lang('COM_AKEEBA_TRANSFER_TITLE')
		(<em>{{{$postProcEngine}}}</em>)
	</a>
@endif

<div style="padding-bottom: 3pt">
	@if ($showDownload)
	<a class="btn {{$showManageRemote || $showUploadRemote ? 'btn-small' : 'btn-success'}} modal"
	   href="#akeeba-buadmin-download-{{(int)$record['id']}}"
	   rel="{handler: 'clone', target: '#akeeba-buadmin-download-{{(int)$record['id']}}', size: {x: 450, y: 280}}">
		<span class="fa fa-fw fa-download"></span>
		@lang('COM_AKEEBA_BUADMIN_LOG_DOWNLOAD')
	</a>
	@endif

	@if ($showViewLog)
	<a class="btn btn-small akeebaCommentPopover" {{($record['meta'] == 'ok') ? '' : 'disabled="disabled" onclick="return false;"'}}
	   href="index.php?option=com_akeeba&view=Log&tag={{{$record['tag']}}}.{{{$record['backupid']}}}&profileid={{(int)$record['profile_id']}}"
	   title="@lang('COM_AKEEBA_BUADMIN_LBL_LOGFILEID')"
	   data-content="{{{$record['backupid']}}}">
		<span class="fa fa-fw fa-list"></span>
		@lang('COM_AKEEBA_LOG')
	</a>
	@endif

	<a class="btn btn-small modal"
	   	href="#akeeba-buadmin-{{(int)$record['id']}}"
		title="@lang('COM_AKEEBA_BUADMIN_LBL_BACKUPINFO')"
	    rel="{handler: 'clone', target: '#akeeba-buadmin-{{(int)$record['id']}}', size: {x: 450, y: 280}}">
		<span class="fa fa-fw fa-info"></span>
	</a>
</div>